@@ -1,4 +1,5 @@
 from mle_training_housing.utils import *
+from mle_training_housing.utils import CombinedAttributesAdder
 
 
 def main():
@@ -51,25 +52,6 @@ def main():
 
     housing["income_cat"] = pd.cut(housing["median_income"], bins=[0.0, 1.5, 3.0, 4.5, 6.0, np.inf], labels=[1, 2, 3, 4, 5],)
 
-    rooms_ix, bedrooms_ix, population_ix, households_ix = 3, 4, 5, 6
-
-    class CombinedAttributesAdder(BaseEstimator, TransformerMixin):
-        def __init__(self, add_bedrooms_per_room=True):  # no *args or **kargs
-            self.add_bedrooms_per_room = add_bedrooms_per_room
-
-        def fit(self, X, y=None):
-            return self  # nothing else to do
-
-        def transform(self, X):
-            rooms_per_household = X[:, rooms_ix] / X[:, households_ix]
-            population_per_household = X[:, population_ix] / X[:, households_ix]
-            if self.add_bedrooms_per_room:
-                bedrooms_per_room = X[:, bedrooms_ix] / X[:, rooms_ix]
-                return np.c_[X, rooms_per_household, population_per_household, bedrooms_per_room]
-
-            else:
-                return np.c_[X, rooms_per_household, population_per_household]
-
     # attr_adder = CombinedAttributesAdder(add_bedrooms_per_room=True)
     # housing_extra_attribs = attr_adder.transform(housing.values)
 
